@@ -767,7 +767,7 @@ class VariableClBuilderImageFilename(Variable):
                 isoname = "%s-%s-%s.iso" % (shortname, buildnumber,
                                             arch)
             fullname = ""
-            for i_dn in filter(None, (dn, addon_dn)):
+            for i_dn in filter(None, (addon_dn, dn)):
                 fullname = path.join(i_dn, isoname)
                 if not rewrite and path.exists(fullname):
                     break
